==> apache-camel-4.7.0-src.zip: apache-camel-4.7.0/components/camel-ai/camel-djl/src/main/java/org/apache/camel/component/djl/DJLProducer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.djl;

import org.apache.camel.Exchange;
import org.apache.camel.component.djl.model.AbstractPredictor;
import org.apache.camel.component.djl.model.ModelPredictorProducer;
import org.apache.camel.support.DefaultProducer;

public class DJLProducer extends DefaultProducer {
    private final AbstractPredictor predictor;

    public DJLProducer(DJLEndpoint endpoint) throws Exception {
        super(endpoint);
        if (endpoint.getArtifactId() != null) {
            this.predictor = ModelPredictorProducer.getZooPredictor(
                    endpoint.getApplication(), endpoint.getArtifactId());
        } else {
            this.predictor = ModelPredictorProducer.getCustomPredictor(
                    endpoint.getApplication(), endpoint.getModel(), endpoint.getTranslator());
        }
    }

    public void process(Exchange exchange) throws Exception {
        this.predictor.process(exchange);
    }
}

==> apache-camel-4.17.0-src.zip: apache-camel-4.17.0/components/camel-ai/camel-djl/src/main/java/org/apache/camel/component/djl/DJLProducer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.djl;

import org.apache.camel.Exchange;
import org.apache.camel.component.djl.model.AbstractPredictor;
import org.apache.camel.component.djl.model.ModelPredictorProducer;
import org.apache.camel.support.DefaultProducer;

public class DJLProducer extends DefaultProducer {
    private final AbstractPredictor predictor;

    public DJLProducer(DJLEndpoint endpoint) throws Exception {
        super(endpoint);
        if (endpoint.getArtifactId() != null) {
            this.predictor = ModelPredictorProducer.getZooPredictor(endpoint);
        } else {
            this.predictor = ModelPredictorProducer.getCustomPredictor(endpoint);
        }
    }

    public void process(Exchange exchange) throws Exception {
        this.predictor.process(exchange);
    }
}
